capture log close
drop _all

****************************************************************************
*****  This file creates individuals'and couples records from the CPS file *
*****  for 1962 - 2015.                 							       *
*****  Input files: cps_00014.dta                                 *
*****  Output file: CPS_march_6215_ind_couple.dta				           *
****************************************************************************

set more 1
set mem 1400m 


log using "c:\temp\cpslog1.log", replace

use "C:\Users\osnat\Documents\aosnat\EK\source_data\cps_00014.dta", clear

compress
* rename variables
rename wkswork1  weeks
rename wkswork1_sp  weeks_sp
rename classwly	class
rename classwly_sp	class_sp
rename famunit famnum


rename nchlt5  child6
rename nchild child18
rename wtsupp wgt

rename inclongj incer1
rename oincwage incwg1
rename uhrsworkly hours
rename incwelfr welfare

rename incwage_sp incwag_sp
rename inclongj_sp incer1_sp
rename oincwage_sp incwg1_sp
rename uhrsworkly_sp hours_sp
rename incwelfr_sp welfare_sp


* keep only civilian adults (drop armed forces and children)
keep 	if popstat == 1
drop 	popstat

* complete missing values
replace	wgt     = 0 if wgt     == .
* complete weeks for 1962-1976 using the grouped variable wkswork2, the values are according to the distribution 
* of the variable wkswork1 at 1977-1980 
replace weeks   = 8    if weeks   == . & wkswork2 ==1
replace weeks   = 21.3 if weeks   == . & wkswork2 ==2
replace weeks   = 34.1 if weeks   == . & wkswork2 ==3
replace weeks   = 43   if weeks   == . & wkswork2 ==4
replace weeks   = 48.3 if weeks   == . & wkswork2 ==5
replace weeks   = 51.9 if weeks   == . & wkswork2 ==6
replace weeks   = 0    if weeks   == . 
replace weeks_sp   = 8    if weeks_sp   == . & wkswork2_sp ==1
replace weeks_sp   = 21.3 if weeks_sp   == . & wkswork2_sp ==2
replace weeks_sp   = 34.1 if weeks_sp   == . & wkswork2_sp ==3
replace weeks_sp   = 43   if weeks_sp   == . & wkswork2_sp ==4
replace weeks_sp   = 48.3 if weeks_sp   == . & wkswork2_sp ==5
replace weeks_sp   = 51.9 if weeks_sp   == . & wkswork2_sp ==6
replace weeks_sp   = 0    if weeks_sp   == . 

replace class   = 0 if class   == 6 | class == 9 | class == .
replace incwage  = 0 if incwage  == .
replace incer1  = 0 if incer1  == .
replace incwg1  = 0 if incwg1  == .
replace hours   = ahrsworkt if  empstat==10 & year<1976
replace hours   = 0 if  hours>97
replace welfare= 0 if welfare == .

replace class_sp   = 0 if class_sp   == 6 | class_sp == 9 | class_sp == .
replace incwag_sp  = 0 if incwag_sp  == .
replace incer1_sp  = 0 if incer1_sp  == .
replace incwg1_sp  = 0 if incwg1_sp  == .
replace hours_sp   = ahrsworkt_sp if empstat_sp==10 & year<1976
replace hours_sp   = 0 if hours_sp>97
replace welfare_sp= 0 if welfare_sp == .

replace child6  = 0 if child6  == . & year >= 1962 & year <= 1967
replace child18 = 0 if child18 == . & year >= 1962


gen emp_stat=1 if empstat==10
replace emp_stat=2 if empstat==12
replace emp_stat=3 if empstat>19 & empstat<30
replace emp_stat=7 if empstat>29 & empstat<40
label var    emp_stat "Employment status last week"
label define emp_stat 1 "EMP" 2 "ABSENT" 3 "UNEMP" 7 "OLF"
label values emp_stat emp_stat
drop empstat

gen emp_stat_sp=1 if empstat_sp==10
replace emp_stat_sp=2 if empstat_sp==12
replace emp_stat_sp=3 if empstat_sp>19 & empstat_sp<30
replace emp_stat_sp=7 if empstat_sp>29 & empstat_sp<40
label var    emp_stat_sp "Employment status last week"
label define emp_stat_sp 1 "EMP" 2 "ABSENT" 3 "UNEMP" 7 "OLF"
label values emp_stat_sp emp_stat_sp
drop empstat_sp

* update marital status - join Married spouse present and Married spouse absent
gen marstat=marst
replace marstat = 1 if marst == 2
replace marstat =4 if marst==5
replace marstat =5 if marst==4
replace marstat =. if marst==9
label define marstat 1 "Married (inc. spouse absent)" 3 "Separated" 4 "Widowed" 5 "Divorced" 6 "Never married"
label values marstat marstat
drop marst

* update marital status - join Married spouse present and Married spouse absent
gen marstat_sp=marst_sp
replace marstat_sp = 1 if marst_sp == 2
replace marstat_sp =4 if marst_sp==5
replace marstat_sp =5 if marst_sp==4
replace marstat_sp =. if marst_sp==9

label define marstat_sp 1 "Married (inc. spouse absent)" 3 "Separated" 4 "Widowed" 5 "Divorced" 6 "Never married"
label values marstat_sp marstat_sp
drop marst_sp

* label relation to head of houeshold
gen relation=1 if relate==0101
replace relation=3 if relate==0201
replace relation=4 if relate==0301
replace relation=4 if relate==0303
replace relation=5 if relate==0501 |relate==0701|relate==0901| relate==1001
replace relation=6 if relate>1001 &  relate<1260
replace relation=7 if relate>9000 &  relate<10000
replace relation=8 if relate==1114

label define relation 1 "Head or primary individual" 3 "Spouse" 4 "Child or other relative" 5 "Secondary family member" 6 "Partner / roommate" 7 "Secondary individual" 8 "unmarried partner/ cohabit"
label values relation relation
drop relate

* label relation to head of houeshold
gen relation_sp=1 if relate_sp==0101
replace relation_sp=3 if relate_sp==0201
replace relation_sp=4 if relate_sp==0301
replace relation_sp=4 if relate_sp==0303
replace relation_sp=5 if relate_sp==0501 |relate_sp==0701|relate_sp==0901| relate_sp==1001
replace relation_sp=6 if relate_sp>1001 &  relate_sp<1260
replace relation_sp=7 if relate_sp>9000 &  relate_sp<10000
replace relation_sp=8 if relate_sp==1114

label define relation_sp 1 "Head or primary individual" 3 "Spouse" 4 "Child or other relative" 5 "Secondary family member" 6 "Partner / roommate" 7 "Secondary individual" 8 "unmarried partner/ cohabit"
label values relation_sp relation_sp
drop relate_sp

* generate education groups
* EDUC is a recoded combination of two other variables, HIGRADE and EDUC99,
* which measure educational attainment in different ways. 
*HIGRADE, available for years prior to 1992, gives the respondent's highest grade of school or year of college completed.
* EDUC99, available beginning in 1992, classifies high school graduates according to their highest degree or diploma attained.
* In EDUC, the HIGRADE categories are given the same codes as their approximate EDUC99 equivalents.

rename educ educyr
gen educ   = 1 if educyr <= 71 & educyr > 1
replace educ   = 2 if educyr == 72 |educyr == 73
replace educ   = 3 if educyr >= 80  & educyr < 111
replace educ   = 4 if educyr >= 111 & educyr <= 122
replace educ   = 5 if educyr >= 123 & educyr <= 125
replace educ   = 3 if higrade >150 & higrade < 190 & year<1992
replace educ   = 4 if higrade >= 190 & higrade < 210 & year<1992
replace educ   = 5 if higrade == 210 & year<1992
drop    higrade  educ99
label var educ "Education group"
label define educ 1 "HSD" 2 "HSG" 3 "SC" 4 "CG" 5 "PC"
label values educ educ

* generate education group dummies
gen hsd = (educ == 1)
gen hsg = (educ == 2)
gen sc  = (educ == 3)
gen cg  = (educ == 4)
gen pc  = (educ == 5)
label var hsd "HSD"
label var hsg "HSG"
label var sc  "SC"
label var cg  "CG"
label var pc  "PC"

* generate experience
gen     age_m_school = age - 17 if educ == 1
replace age_m_school = age - 18 if educ == 2
replace age_m_school = age - 20 if educ == 3
replace age_m_school = age - 22 if educ == 4
replace age_m_school = age - 24 if educ == 5
label var age_m_school "age - schooling"

rename educ_sp educyr_sp
gen educ_sp   = 1 if educyr_sp <= 71 & educyr > 1
replace educ_sp   = 2 if educyr_sp == 72 |educyr_sp == 73
replace educ_sp   = 3 if educyr_sp >= 80 &  educyr_sp < 111
replace educ_sp   = 4 if educyr_sp >= 111 & educyr_sp <= 122
replace educ_sp   = 5 if educyr_sp >= 123 & educyr_sp <= 125
replace educ_sp   = 3 if higrade_sp >150 & higrade_sp < 190 & year<1992
replace educ_sp   = 4 if higrade_sp >= 190 & higrade_sp < 210 & year<1992
replace educ_sp   = 5 if higrade_sp == 210 & year<1992
drop    higrade_sp  educ99_sp
label var educ_sp "Education group"
label define educ_sp 1 "HSD" 2 "HSG" 3 "SC" 4 "CG" 5 "PC"
label values educ_sp educ_sp

* generate education group dummies
gen hsd_sp = (educ_sp == 1)
gen hsg_sp = (educ_sp == 2)
gen sc_sp  = (educ_sp == 3)
gen cg_sp  = (educ_sp == 4)
gen pc_sp  = (educ_sp == 5)
label var hsd_sp "HSD"
label var hsg_sp "HSG"
label var sc_sp  "SC"
label var cg_sp  "CG"
label var pc_sp  "PC"

* generate experience
* generate experience
gen     age_m_school_sp = age_sp - 17 if educ_sp == 1
replace age_m_school_sp = age_sp - 18 if educ_sp == 2
replace age_m_school_sp = age_sp - 20 if educ_sp == 3
replace age_m_school_sp = age_sp - 22 if educ_sp == 4
replace age_m_school_sp = age_sp - 24 if educ_sp == 5
label var age_m_school_sp "age - schooling"

* generate cohort, except for top coded and grouped ages
gen     cohort = year - age
replace cohort = 0 if  age == 90 & year >= 1989 & year <= 2001
replace cohort = 0 if  age == 80 & year >= 2002 & year <= 2003
replace cohort = 0 if (age == 80 | age == 85) & year >= 2004
label var cohort "Cohort (Year of birth)"

* generate household ID
* SERIAL is an identifying number unique to each household in a given survey month and year. 
* All person records are assigned the same serial number as the household record they follow. 
* A combination of YEAR, MONTH, and SERIAL provides a within-sample unique identifier for every household in IPUMS-CPS;
* YEAR, SERIAL, and PERNUM uniquely identify every person in the database within sample.
* SERIAL is a new value generated for IPUMS-CPS and should not be confused with the househ

rename  serial   house
label var house "Household ID"

* generate full time full year indicator
gen     ftfy = 0
replace ftfy = 1 if weeks >=40 & fullpart==1 
label var ftfy "Full time full year (35+ hours per week last year, 40+ weeks last year)"

gen     ftfy_sp = 0
replace ftfy_sp = 1 if weeks_sp >=40 & fullpart_sp==1 
label var ftfy_sp "Full time full year (35+ hours per week last year, 40+ weeks last year)"

* replace 999999999   to missing
replace incwage=0 if incwage>2000000 
* generate wage top coding indicator

gen     topcode = 0
replace topcode = 1 if incwage == 99900                    & year >= 1962 & year <= 1967
replace topcode = 1 if incwage == 50000                    & year >= 1968 & year <= 1981
replace topcode = 1 if incwage == 75000                    & year >= 1982 & year <= 1984
replace topcode = 1 if incwage == 99999                    & year >= 1985 & year < 1988
replace topcode = 1 if incwage == 199998                    & year == 1994
replace topcode = 1 if incwage == 199998                    & year == 1995

* update top coded wages
replace incwage = incwage * 1.75 if topcode == 1 & year <= 1995
drop topcode

* generate annualized wages (for 52 weeks)
gen     annual_wage = incwage * 52 /weeks
replace annual_wage = 0 if annual_wage == .

* generate weekly wage
gen     week_wage = incwage / weeks
replace week_wage = 0 if week_wage == .
drop incwage weeks

* generate hourly wages
gen     hour_wage = week_wage / hours if hours<200
replace hour_wage = 0 if hour_wage == .


* replace 999999999   to missing
replace incwag_sp=0 if incwag_sp>2000000 
* generate wage top coding indicator
gen     topcode_sp = 0
replace topcode_sp = 1 if incwag_sp == 99900                    & year >= 1962 & year <= 1967
replace topcode_sp = 1 if incwag_sp == 50000                    & year >= 1968 & year <= 1981
replace topcode_sp = 1 if incwag_sp == 75000                    & year >= 1982 & year <= 1984
replace topcode_sp = 1 if incwag_sp == 99999                    & year >= 1985 & year < 1988
replace topcode_sp = 1 if incwag_sp == 199998                    & year == 1994
replace topcode_sp = 1 if incwag_sp == 199998                    & year == 1995

* update top coded wages
replace incwag_sp = incwag_sp * 1.75 if topcode_sp == 1 & year <= 1995
drop topcode_sp

* generate annualized wages (for 52 weeks)
gen     annual_wage_sp = incwag_sp * 52 /weeks_sp
replace annual_wage_sp = 0 if annual_wage_sp == .

* generate weekly wage
gen     week_wage_sp = incwag_sp / weeks_sp
replace week_wage_sp = 0 if week_wage_sp == .
drop incwag_sp weeks_sp

* generate hourly wages
gen     hour_wage_sp = week_wage_sp / hours_sp if hours_sp<200
replace hour_wage_sp = 0 if hour_wage_sp == .
                 
* generate real wages using PCE (personal consumption expenditure) deflators - NIPA Table 2.3.4 (http://www.bea.gov/bea/dn/nipaweb/index.asp)
* wages refer to last year, so PCE of year X-1 is used for observations of year X
gen pce=	17.939	 if year ==	1962
replace pce = 	18.148	 if year ==	1963
replace pce = 	18.414	 if year ==	1964
replace pce = 	18.681	 if year ==	1965
replace pce = 	19.155	 if year ==	1966
replace pce = 	19.637	 if year ==	1967
replace pce = 	20.402	 if year ==	1968
replace pce = 	21.326	 if year ==	1969
replace pce = 	22.325	 if year ==	1970
replace pce = 	23.274	 if year ==	1971
replace pce = 	24.07	 if year ==	1972
replace pce = 	25.368	 if year ==	1973
replace pce = 	28.009	 if year ==	1974
replace pce = 	30.348	 if year ==	1975
replace pce = 	32.013	 if year ==	1976
replace pce = 	34.091	 if year ==	1977
replace pce = 	36.479	 if year ==	1978
replace pce = 	39.714	 if year ==	1979
replace pce = 	43.978	 if year ==	1980
replace pce = 	47.908	 if year ==	1981
replace pce = 	50.553	 if year ==	1982
replace pce = 	52.729	 if year ==	1983
replace pce = 	54.724	 if year ==	1984
replace pce = 	56.661	 if year ==	1985
replace pce = 	57.887	 if year ==	1986
replace pce = 	59.65	 if year ==	1987
replace pce = 	61.974	 if year ==	1988
replace pce = 	64.641	 if year ==	1989
replace pce = 	67.44	 if year ==	1990
replace pce = 	69.652	 if year ==	1991
replace pce = 	71.494	 if year ==	1992
replace pce = 	73.279	 if year ==	1993
replace pce = 	74.803	 if year ==	1994
replace pce = 	76.356	 if year ==	1995
replace pce = 	77.981	 if year ==	1996
replace pce = 	79.327	 if year ==	1997
replace pce = 	79.936	 if year ==	1998
replace pce = 	81.11	 if year ==	1999
replace pce = 	83.131	 if year ==	2000
replace pce = 	84.736	 if year ==	2001
replace pce = 	85.873	 if year ==	2002
replace pce = 	87.572	 if year ==	2003
replace pce = 	89.703	 if year ==	2004
replace pce = 	92.261	 if year ==	2005
replace pce = 	94.729	 if year ==	2006
replace pce = 	97.102	 if year ==	2007
replace pce = 	100.065	 if year ==	2008
replace pce = 	100	 if year ==	2009
replace pce = 	101.653	 if year ==	2010
replace pce = 	104.149	 if year ==	2011
replace pce = 	106.121	 if year ==	2012
replace pce = 	107.572	 if year ==	2013
replace pce = 	109.105	 if year ==	2014
replace pce = 	109.44	 if year ==	2015
label var pce "PCE, base year is 2009"
gen real_hourwage = hourwage / pce * 100
drop hourwage
gen real_annual_wage = annual_wage / pce * 100
drop annual_wage
gen real_week_wage   = week_wage   / pce * 100
drop week_wage
gen real_hour_wage   = hour_wage   / pce * 100
drop hour_wage
gen real_welfare = welfare / pce * 100
drop welfare
label var real_annual_wage "Annualized real wage (for 52 weeks), top coded wages until 1995 updated"
label var real_week_wage   "Weekly wage, top coded wages until 1995 updated"
label var real_hour_wage   "Hourly real wage (using hours last week), top coded wages until 1995 updated"
label var real_welfare     "Annualized pre-tax real welfare payments"
drop if real_welfare>100000


gen real_hourwage_sp = hourwage_sp / pce * 100
drop hourwage_sp
gen real_annual_wage_sp = annual_wage_sp / pce * 100
drop annual_wage_sp
gen real_week_wage_sp   = week_wage_sp   / pce * 100
drop week_wage_sp
gen real_hour_wage_sp   = hour_wage_sp   / pce * 100
drop hour_wage_sp
gen real_welfare_sp = welfare_sp / pce * 100
drop welfare_sp
label var real_annual_wage_sp "Annualized real wage (for 52 weeks), top coded wages until 1995 updated"
label var real_week_wage_sp   "Weekly wage, top coded wages until 1995 updated"
label var real_hour_wage_sp   "Hourly real wage (using hours last week), top coded wages until 1995 updated"
label var real_welfare_sp     "Annualized pre-tax real welfare payments"
drop if real_welfare_sp>100000

* generate cohort group
*gen     cohort_g = 1915 if cohort >= 1913 & cohort <= 1917
*replace cohort_g = 1920 if cohort >= 1918 & cohort <= 1922
gen cohort_g = 1925 if cohort >= 1923 & cohort <= 1927
*replace cohort_g = 1930 if cohort >= 1928 & cohort <= 1932
replace cohort_g = 1935 if cohort >= 1933 & cohort <= 1937
*replace cohort_g = 1940 if cohort >= 1938 & cohort <= 1942
replace cohort_g = 1945 if cohort >= 1943 & cohort <= 1947
*replace cohort_g = 1950 if cohort >= 1948 & cohort <= 1952
replace cohort_g = 1955 if cohort >= 1953 & cohort <= 1957
*replace cohort_g = 1960 if cohort >= 1958 & cohort <= 1962
replace cohort_g = 1965 if cohort >= 1963 & cohort <= 1967
*replace cohort_g = 1970 if cohort >= 1968 & cohort <= 1972
replace cohort_g = 1975 if cohort >= 1973 & cohort <= 1977
*replace cohort_g = 1980 if cohort >= 1978 & cohort <= 1982
replace cohort_g = 1985 if cohort >= 1983 & cohort <= 1987
*replace cohort_g = 1990 if cohort >= 1988 & cohort <= 1992
*********************************************************************************************
*100	White	/ 200	Black/Negro	 / 300	American Indian/Aleut/Eskimo
*650	Asian or Pacific Islander	/ 651	Asian only	/ 652	Hawaiian/Pacific Islander only	
*700	Other (single) 
****  Two or more races    ****	
*801	White-Black	/ 802	White-American Indian	 /803	White-Asian /804	White-Hawaiian/Pacific Islander
*805	Black-American Indian /806	Black-Asian /807	Black-Hawaiian/Pacific Islander	/ 808	American Indian-Asian
*809	Asian-Hawaiian/Pacific Islander /810	White-Black-American Indian	/811	White-Black-Asian	/812	White-American Indian-Asian	
*813	White-Asian-Hawaiian/Pacific Islander /815	American Indian-Hawaiian/Pacific Islander	/816	White-Black--Hawaiian/Pacific Islander	
*817	White-American Indian-Hawaiian/Pacific Islander	/818	Black-American Indian-Asian	/819	White-American Indian-Asian-Hawaiian/Pacific Islander
*830	Four or five races, unspecified /999	Blank
********************************************************************************************
*000	Not Hispanic   /100	Mexican	/102	Mexican American /103	Mexicano/Mexicana /104	Chicano/Chicana
*108	Mexican (Mexicano) /109	Mexicano/Chicano / 200	Puerto Rican / 300	Cuban	 / 400	Dominican 
*500	Salvadoran / 401	Other Hispanic  /410	Central/South American /411	Central American, (excluding Salvadoran)
*412	South American / 901	Do not know 902	Not available/no response
*******************************************************************************************
* keep black and hispanic
gen black=(race==200 & hispan==0)       
* black but not hispanic. excluding half-black
gen hispanic=(hispan>0 & hispan!=.)
gen minor=1 if black==1
replace minor=2 if hispanic==1
*******************************************************************************************
* generate participation indicator
gen participant = (emp_stat < 7)
* generate employment indicator
gen employed = (emp_stat == 1 & hours >= 10  & hours<200 )
replace employed=1 if emp_stat == 1 & hours == 0
replace employed=. if emp_stat==.
* generate hours last week for employed people
gen hours_nonzero = hours if emp_stat == 1
gen emp = (emp_stat == 1)
replace emp=. if emp_stat==.
gen unemployed = 1 if emp_stat==3
replace unemployed = 1 if (emp_stat == 1 | hours < 10)
replace unemployed = 1 if (emp_stat == 2 | hours < 10)
gen full_time = (fullpart==1)
gen part_time = (fullpart==2)
label define fullpart 0 "unemployed" 1 "part time" 2 "full time"
******************************************************************************************
replace wgt=round(wgt*100,0)
* generate hourly wage for employed people, employed people only in private and government, employed people with non-zero wage, and employed people with wage above the minimum wage
gen hour_wage         = real_hour_wage if emp_stat <= 1
gen hourwage = real_hourwage if emp_stat <= 1
gen hour_wage_not_self_emp = real_hour_wage if emp_stat <= 1 & (class > 19 & class < 29)
gen hour_wage_nonzero = real_hour_wage if emp_stat <= 1 & real_hour_wage != 0
gen hour_wage_minimum = real_hour_wage if emp_stat <= 1 & real_hour_wage >= 1
gen hourwage_nonzero = real_hourwage if emp_stat <= 1 & real_hourwage != 0

gen hour_wage_sp         = real_hour_wage_sp if emp_stat_sp <= 1
gen hourwage_sp = real_hourwage_sp if emp_stat_sp <= 1
gen hour_wage_not_self_emp_sp = real_hour_wage_sp if emp_stat_sp <= 1 & (class_sp > 19 & class_sp < 29)
gen hour_wage_nonzero_sp = real_hour_wage_sp if emp_stat_sp <= 1 & real_hour_wage_sp != 0
gen hour_wage_minimum_sp = real_hour_wage_sp if emp_stat_sp <= 1 & real_hour_wage_sp >= 1
gen hourwage_nonzero_sp = real_hourwage_sp if emp_stat_sp <= 1 & real_hourwage_sp != 0

* generate annual wage for all, only in private and government, people with non-zero wage, people with wage above the minimum wage, and full time full year workers
gen annual_wage              = real_annual_wage
gen annual_wage_not_self_emp      = real_annual_wage if (class > 19 & class < 29)
gen annual_wage_nonzero      = real_annual_wage if real_annual_wage != 0
gen annual_wage_minimum      = real_annual_wage if real_annual_wage >= 35*40
gen annual_wage_ftfy         = real_annual_wage if                             ftfy == 1
gen annual_wage_ftfy_not_self_emp = real_annual_wage if (class > 19 & class < 29) & ftfy == 1 
gen annual_wage_nonzero_ftfy = real_annual_wage if real_annual_wage != 0     & ftfy == 1
gen annual_wage_minimum_ftfy = real_annual_wage if real_annual_wage >= 35*40 & ftfy == 1
    
gen annual_wage_sp              = real_annual_wage_sp
gen annual_wage_not_self_emp_sp      = real_annual_wage_sp if (class_sp > 19 & class_sp < 29)
gen annual_wage_nonzero_sp      = real_annual_wage_sp if real_annual_wage_sp != 0
gen annual_wage_minimum_sp      = real_annual_wage_sp if real_annual_wage_sp >= 35*40
gen annual_wage_ftfy_sp         = real_annual_wage_sp if                             ftfy_sp == 1
gen annual_wage_ftfy_not_self_emp_sp = real_annual_wage_sp if (class_sp > 19 & class_sp < 29) & ftfy_sp == 1 
gen annual_wage_nonzero_ftfy_sp = real_annual_wage_sp if real_annual_wage_sp != 0     & ftfy_sp == 1
gen annual_wage_minimum_ftfy_sp = real_annual_wage_sp if real_annual_wage_sp >= 35*40 & ftfy_sp == 1
*********************************************************************************************************
* generate number of children groups
gen     child6_group  = 0
replace child6_group  = 1 if child6  == 0
replace child6_group  = 2 if child6  >  0 & child6  <= 1
replace child6_group  = 3 if child6  >  1 & child6  <= 3
replace child6_group  = 4 if child6  >  3 & child6  != .
gen     child18_group = 0
replace child18_group = 1 if child18 == 0
replace child18_group = 2 if child18 >  0 & child18 <= 1
replace child18_group = 3 if child18 >  1 & child18 <= 3
replace child18_group = 4 if child18 >  3 & child18 != .
label define child_group 1 "0" 2 "1" 3 "2-3" 4 "4+"
label values child6_group  child_group
label values child18_group child_group

compress

save "C:\Users\osnat\Documents\aosnat\EK\source_data\CPS_march_6215_ind_couple.dta", replace
log close
