
capture log close
drop _all

*************************************************************************
*****  This file creates the EKL model's moments for 1935-75 cohorts	*
*****  Input file:  CPS_march_6214_ind_couple.dta						*
*************************************************************************

set more 1
set mem 950m


use "C:\Users\osnat\Documents\aosnat\EK\source_data\CPS_march_6214_ind_couple.dta", clear
* generate cohort group
gen     cohort_g = 1925 if cohort >= 1923 & cohort <= 1927
replace cohort_g = 1935 if cohort >= 1933 & cohort <= 1937
replace cohort_g = 1945 if cohort >= 1943 & cohort <= 1947
replace cohort_g = 1955 if cohort >= 1953 & cohort <= 1957
replace cohort_g = 1965 if cohort >= 1963 & cohort <= 1967
replace cohort_g = 1975 if cohort >= 1973 & cohort <= 1977
replace cohort_g = 1985 if cohort >= 1983 & cohort <= 1987

* keep relevant population - ages 16-65
keep if age >= 16 & age <= 65 & race==100

* generate participation indicator
gen participant = (emp_stat < 7)

* generate employment indicator
gen employed = (emp_stat == 1 & hours >= 10)
gen unemployed = (emp_stat != 1 | hours < 10)
gen full_time = (emp_stat == 1 & hours >= 35)
gen part_time = (emp_stat == 1 & hours < 35 & hours >= 10)
gen ls_status = 0 if employed == 0
replace ls_status = 1 if part_time==1
replace ls_status = 2 if full_time==1
label define ls_status 0 "unemployed" 1 "part time" 2 "full time"

* generate hours last week for employed people
gen hours_nonzero = hours if emp_stat == 1

*generate marriage dummy, divorce dummy
gen married = 1 if marstat == 1
replace married = 0 if married ==. & marstat!=.
 *generate divorce out of evermarried
gen divorced = 1 if marstat == 5
replace divorced = 0 if divorced ==. & marstat!=.
*generate kids dummy

gen     have_kids = 1 if child18 > 0 & child18 !=.
replace have_kids = 0 if have_kids ==. 

replace wgt=round(wgt*100,0)
* generate hourly wage for employed people, employed people only in private and government, employed people with non-zero wage, and employed people with wage above the minimum wage
gen hour_wage         = real_hour_wage if emp_stat <= 1
gen hour_wage_not_self_emp = real_hour_wage if emp_stat <= 1 & (class > 19 & class < 29)
gen hour_wage_nonzero = real_hour_wage if emp_stat <= 1 & real_hour_wage != 0
gen hour_wage_minimum = real_hour_wage if emp_stat <= 1 & real_hour_wage >= 1

* generate weekly wage for all, people with non-zero wage, and people with wage above the minimum wage
gen week_wage         = real_week_wage
gen week_wage_nonzero = real_week_wage if real_week_wage != 0
gen week_wage_minimum = real_week_wage if real_week_wage >= 35

* generate annual wage for all, only in private and government, people with non-zero wage, people with wage above the minimum wage, and full time full year workers
gen annual_wage              = real_annual_wage
gen annual_wage_not_self_emp      = real_annual_wage if (class > 19 & class < 29)
gen annual_wage_nonzero      = real_annual_wage if real_annual_wage != 0
gen annual_wage_minimum      = real_annual_wage if real_annual_wage >= 35*40
gen annual_wage_ftfy         = real_annual_wage if                             ftfy == 1
gen annual_wage_ftfy_not_self_emp = real_annual_wage if (class > 19 & class < 29) & ftfy == 1 
gen annual_wage_nonzero_ftfy = real_annual_wage if real_annual_wage != 0     & ftfy == 1
gen annual_wage_minimum_ftfy = real_annual_wage if real_annual_wage >= 35*40 & ftfy == 1
******************************************************************************************
* descriptive statistics
******************************************************************************************
tab cohort_g
sort cohort_g
by cohort_g: tab year
by cohort_g: tab marstat if age==40
by cohort_g: tab marstat if age==40
by cohort_g: tab educ if age==40

******************************************************************************************


* keep relevant variables
keep participant employed hours_nonzero year age sex  marstat child18 have_kids educ  wgt annual_wage_nonzero_ftfy married divorced hsd hsg sc cg pc cohort_g educ educ_sp SEX_SP full_time part_time unemployed

*                     marstat |      Freq.     Percent        Cum.
*-----------------------------+-----------------------------------
*Married (inc. spouse absent) - 1 |  3,433,167       57.99       57.99
*                   Separated - 3 |    124,314        2.10       60.09
*                     Widowed - 4 |    396,203        6.69       66.78
*                    Divorced - 5 |    405,173        6.84       73.63
*               Never married - 6 |  1,561,253       26.37      100.00
*                           8     |          1        0.00      100.00
*-----------------------------+-----------------------------------
*                       Total |  5,920,111      100.00
drop if marstat == 8


save "c:\temp\figures.dta", replace
* employment by sex
collapse (mean) employed married divorced child18 annual_wage_nonzero_ftfy full_time part_time unemployed [pw = wgt] if wgt >= 0, by(cohort_g sex  age )
outsheet cohort_g sex  age  employed married divorced child18 annual_wage_nonzero_ftfy full_time part_time unemployed using "c:\temp\emp_mrate_child_wage.out", replace nonames

* by sex for married people (without separate couples)
use "c:\temp\figures.dta", clear
keep if marstat == 1
collapse (mean)  employed married divorced child18 annual_wage_nonzero_ftfy full_time part_time unemployed [pw = wgt] if wgt >= 0, by(cohort_g sex  age )
outsheet cohort_g sex  age  employed married divorced child18 annual_wage_nonzero_ftfy full_time part_time unemployed using "c:\temp\emp_mrate_child_wage_m.out", replace nonames

* by sex for non-married people - only dummy for kids
use "c:\temp\figures.dta", clear
keep if marstat > 1 & marstat!=.
collapse (mean)  employed married divorced have_kids annual_wage_nonzero_ftfy full_time part_time unemployed    [pw = wgt] if wgt >= 0, by(cohort_g sex  age )
outsheet cohort_g sex  age  employed married divorced have_kids annual_wage_nonzero_ftfy full_time part_time unemployed using "c:\temp\emp_mrate_child_wage_um.out", replace nonames

* by sex for divorced people
use "c:\temp\figures.dta", clear
keep if marstat == 5
collapse (mean)  employed married divorced child18 annual_wage_nonzero_ftfy full_time part_time unemployed [pw = wgt] if wgt >= 0, by(cohort_g sex  age )
outsheet cohort_g sex  age  employed married divorced child18 annual_wage_nonzero_ftfy full_time part_time unemployed using "c:\temp\emp_mrate_child_wage_d.out", replace nonames
* no divorce women at age 16, need to add line when creates file!!!!!!!!!!!!!!!!!!!!!!!!

********************************************************************************************************************************
* employment of MARRIED women with kids
use "c:\temp\figures.dta", clear
keep if child18 > 0 & child18 != . & marstat == 1
collapse (mean)  employed  [pw = wgt] if wgt >= 0, by(cohort_g sex   age )
outsheet cohort_g sex   age  employed  using "c:\temp\emp_m_with.out", replace nonames

* employment of married with no kids
use "c:\temp\figures.dta", clear
keep if child18 == 0  & marstat == 1
collapse (mean)  employed  [pw = wgt] if wgt >= 0, by(cohort_g sex   age )
outsheet cohort_g sex   age  employed  using "c:\temp\emp_m_without.out", replace nonames


* employment of unmarried women with kids
use "c:\temp\figures.dta", clear
keep if child18 > 0 & child18 != . & marstat > 1 & marstat!=.
collapse (mean)  employed  [pw = wgt] if wgt >= 0, by(cohort_g sex   age )
outsheet cohort_g sex   age  employed  using "c:\temp\emp_um_with.out", replace nonames

* employment of unmarried with no kids
use "c:\temp\figures.dta", clear
keep if child18 == 0  & marstat > 1 & marstat!=.
collapse (mean)  employed  [pw = wgt] if wgt >= 0, by(cohort_g sex   age )
outsheet cohort_g sex   age cohort_g employed  using "c:\temp\emp_um_without.out", replace nonames
******************************************************************************************************************

* employment by education
use "c:\temp\figures.dta", clear
keep if year >= 1964
drop if age<20
collapse (mean)  employed annual_wage_nonzero_ftfy [pw = wgt] if wgt >= 0, by(cohort_g sex  educ age )
outsheet cohort_g sex educ  age  employed annual_wage_nonzero_ftfy using "c:\temp\emp_wage_by_educ.out", replace nonames
* can't import to C++ as is, need some edit since some data is missing

* employment by education married
use "c:\temp\figures.dta", clear
keep if year >= 1964
drop if age<20
keep if marstat == 1
collapse (mean)  employed annual_wage_nonzero_ftfy [pw = wgt] if wgt >= 0, by(cohort_g sex educ age  )
outsheet cohort_g sex educ  age employed annual_wage_nonzero_ftfy  using "c:\temp\emp_wage_by_educ_m.out", replace nonames
* can't import to C++ as is, need some edit since some data is missing

* employment by education unmarried
use "c:\temp\figures.dta", clear
keep if year >= 1964
drop if age<20
keep if  marstat > 1 & marstat!=.
collapse (mean)  employed annual_wage_nonzero_ftfy [pw = wgt] if wgt >= 0, by(cohort_g sex educ age )
outsheet cohort_g sex educ  age  employed annual_wage_nonzero_ftfy  using "c:\temp\emp_wage_by_educ_um.out", replace nonames
* can't import to C++ as is, need some edit since some data is missing

*****************************************************************************************************************
* educational composition of population 
use "c:\temp\figures.dta", clear
keep if year >= 1964
collapse (mean) hsd hsg sc cg pc [pw = wgt] if wgt >= 0, by(cohort_g sex  age )
outsheet cohort_g sex age  hsd hsg sc cg pc using "c:\temp\educ_comp.out", replace nonames

* educational composition of married
use "c:\temp\figures.dta", clear
keep if year >= 1964
keep if marstat == 1
collapse (mean) hsd hsg sc cg pc [pw = wgt] if wgt >= 0, by(cohort_g sex  age )
outsheet cohort_g sex age  hsd hsg sc cg pc using "c:\temp\educ_comp_m.out", replace nonames

* educational composition of unmarried
use "c:\temp\figures.dta", clear
keep if year >= 1964
keep if  marstat > 1 & marstat!=.
collapse (mean) hsd hsg sc cg pc [pw = wgt] if wgt >= 0, by(cohort_g sex  age )
outsheet cohort_g sex age  hsd hsg sc cg pc using "c:\temp\educ_comp_um.out", replace nonames

*************************************************************************************************************
* assortative mating
use "c:\temp\figures.dta", clear
keep if year >= 1964
keep if marstat == 1

tab  educ  educ_sp if  marstat==1 & cohort_g==1925 & sex==2 & SEX_SP==1 & age>29 & age<41, nofreq column nolabel
tab  educ  educ_sp if  marstat==1 & cohort_g==1935 & sex==2 & SEX_SP==1 & age>29 & age<41, nofreq column nolabel
tab  educ  educ_sp if  marstat==1 & cohort_g==1945 & sex==2 & SEX_SP==1 & age>29 & age<41, nofreq column nolabel
tab  educ  educ_sp if  marstat==1 & cohort_g==1955 & sex==2 & SEX_SP==1 & age>29 & age<41, nofreq column nolabel
tab  educ  educ_sp if  marstat==1 & cohort_g==1965 & sex==2 & SEX_SP==1 & age>29 & age<41, nofreq column nolabel
tab  educ  educ_sp if  marstat==1 & cohort_g==1975 & sex==2 & SEX_SP==1 & age>29 & age<41, nofreq column nolabel
tab  educ  educ_sp if  marstat==1 & cohort_g==1985 & sex==2 & SEX_SP==1 & age>29 & age<41, nofreq column nolabel




