
capture log close
drop _all

************************************************************
*****  This file creates health data from the IHIS file    *
*****  Input file:  health.dta				               *
*****  Output file: health_edit.dta				           *
************************************************************

set more 1
set mem 900m 


log using "c:\Users\osnat\Documents\aosnat\EK\health_data\ihislog2.log", replace

*use "C:\Users\osnat\Documents\aosnat\EK\source_data\health2015.dta", clear

*generate a 3 level health index
gen health3=1 if health<3
replace health3=2 if health>2 & health<5
replace health3=3 if health==5


* keep only white
drop if  racea!=100

* generate year of birth
gen y_birth= year- age

* keep relevant cohort
gen     cohort_g = 1925 if y_birth >= 1923 & y_birth <= 1927
replace cohort_g = 1935 if y_birth >= 1933 & y_birth <= 1937
replace cohort_g = 1945 if y_birth >= 1943 & y_birth <= 1947
replace cohort_g = 1955 if y_birth >= 1953 & y_birth <= 1957
replace cohort_g = 1965 if y_birth >= 1963 & y_birth <= 1967
replace cohort_g = 1975 if y_birth >= 1973 & y_birth <= 1977
replace cohort_g = 1985 if y_birth >= 1983 & y_birth <= 1987 

drop if age<17 | age>61

*initial health distribution for white women, age 16, cohort 1955 - no need, we use 1 (good) for all
tab health3 if sex==2 & age==16 & cohort_g==1945
tab health3 if sex==2 & age==16 & cohort_g==1955
tab health3 if sex==2 & age==16 & cohort_g==1965

*initial health distribution for white women, age 16, cohort 1955 - no need, we use 1 (good) for all
tab health3 if sex==1 & age==16 & cohort_g==1945
tab health3 if sex==1 & age==16 & cohort_g==1955
tab health3 if sex==1 & age==16 & cohort_g==1965


*    health3 |      Freq.     Percent        Cum.
*------------+-----------------------------------
*          1 |      1,276       58.96       58.96
*          2 |        876       40.48       99.45
*          3 |         12        0.55      100.00
*------------+-----------------------------------
*      Total |      2,164      100.00

use "c:\Users\osnat\Documents\aosnat\EK\health_data\health_edit.dta", clear

* generate health group dummies (cummulative distribution)
keep if health3!=.
gen m_1 = (health3 <= 1)
gen m_2 = (health3 <= 2)
gen m_3 = (health3 <= 3)

keep if cohort_g==1935 |cohort_g==1945 |  cohort_g==1955 |cohort_g==1965 |cohort_g==1975
* husbands' distribution 
collapse (mean) m_1 m_2 m_3 [fw = sampweight] if sampweight >= 0 , by(sex cohort_g age)

outsheet sex cohort_g age m_1 m_2 m_3 using "C:\Users\osnat\Documents\aosnat\EK\health_data\init_health.out", nolabel nonames replace


