* NOTE: You need to set the Stata working directory to the path
* where the data file is located.

set more off

clear
quietly infix                  ///
  int     year        1-4      ///
  long    serial      5-10     ///
  int     strata      11-14    ///
  int     psu         15-17    ///
  str     nhishid     18-31    ///
  long    hhweight    32-37    ///
  str     nhispid     38-53    ///
  str     hhx         54-59    ///
  str     fmx         60-61    ///
  str     px          62-63    ///
  double  perweight   64-72    ///
  double  sampweight  73-81    ///
  long    fweight     82-87    ///
  byte    astatflg    88-88    ///
  byte    cstatflg    89-89    ///
  byte    pernum      90-91    ///
  byte    age         92-93    ///
  byte    sex         94-94    ///
  byte    marstat     95-96    ///
  int     racea       97-99    ///
  byte    educrec2    100-101  ///
  byte    higrade2    102-103  ///
  byte    educ        104-105  ///
  byte    health      106-106  ///
  str     nhisiid     107-125  ///
  using `"ihis_00004.dat"'


format perweight  %9.0f
format sampweight %9.0f

label var year       `"Survey year"'
label var serial     `"Sequential Serial Number, Household Record"'
label var strata     `"Stratum for variance estimation"'
label var psu        `"Primary sampling unit (PSU) for variance estimation"'
label var nhishid    `"NHIS Unique identifier, household"'
label var hhweight   `"Household weight, final annual"'
label var nhispid    `"NHIS Unique Identifier, person"'
label var hhx        `"Household number (from NHIS)"'
label var fmx        `"Family number (from NHIS)"'
label var px         `"Person number of respondent (from NHIS)."'
label var perweight  `"Final basic annual weight"'
label var sampweight `"Sample Person Weight"'
label var fweight    `"Final annual family weight"'
label var astatflg   `"Sample adult flag"'
label var cstatflg   `"Sample child flag"'
label var pernum     `"Person number within family (from reformatting)"'
label var age        `"Age"'
label var sex        `"Sex"'
label var marstat    `"Legal marital status"'
label var racea      `"Main Racial Background (Pre-1997 Revised OMB Standards), self-reported or interv"'
label var educrec2   `"Educational attainment recode, intervalled"'
label var higrade2   `"Highest grade of schooling completed, intervalled"'
label var educ       `"Educational attainment"'
label var health     `"Health status"'
label var nhisiid    `"NHIS unique identifier, injury"'

label define year_lbl 1963 `"1963"'
label define year_lbl 1964 `"1964"', add
label define year_lbl 1965 `"1965"', add
label define year_lbl 1966 `"1966"', add
label define year_lbl 1967 `"1967"', add
label define year_lbl 1968 `"1968"', add
label define year_lbl 1969 `"1969"', add
label define year_lbl 1970 `"1970"', add
label define year_lbl 1971 `"1971"', add
label define year_lbl 1972 `"1972"', add
label define year_lbl 1973 `"1973"', add
label define year_lbl 1974 `"1974"', add
label define year_lbl 1975 `"1975"', add
label define year_lbl 1976 `"1976"', add
label define year_lbl 1977 `"1977"', add
label define year_lbl 1978 `"1978"', add
label define year_lbl 1979 `"1979"', add
label define year_lbl 1980 `"1980"', add
label define year_lbl 1981 `"1981"', add
label define year_lbl 1982 `"1982"', add
label define year_lbl 1983 `"1983"', add
label define year_lbl 1984 `"1984"', add
label define year_lbl 1985 `"1985"', add
label define year_lbl 1986 `"1986"', add
label define year_lbl 1987 `"1987"', add
label define year_lbl 1988 `"1988"', add
label define year_lbl 1989 `"1989"', add
label define year_lbl 1990 `"1990"', add
label define year_lbl 1991 `"1991"', add
label define year_lbl 1992 `"1992"', add
label define year_lbl 1993 `"1993"', add
label define year_lbl 1994 `"1994"', add
label define year_lbl 1995 `"1995"', add
label define year_lbl 1996 `"1996"', add
label define year_lbl 1997 `"1997"', add
label define year_lbl 1998 `"1998"', add
label define year_lbl 1999 `"1999"', add
label define year_lbl 2000 `"2000"', add
label define year_lbl 2001 `"2001"', add
label define year_lbl 2002 `"2002"', add
label define year_lbl 2003 `"2003"', add
label define year_lbl 2004 `"2004"', add
label define year_lbl 2005 `"2005"', add
label define year_lbl 2006 `"2006"', add
label define year_lbl 2007 `"2007"', add
label define year_lbl 2008 `"2008"', add
label define year_lbl 2009 `"2009"', add
label define year_lbl 2010 `"2010"', add
label define year_lbl 2011 `"2011"', add
label define year_lbl 2012 `"2012"', add
label define year_lbl 2013 `"2013"', add
label define year_lbl 2014 `"2014"', add
label values year year_lbl

label define astatflg_lbl 0 `"NIU"'
label define astatflg_lbl 1 `"Sample adult, has record"', add
label define astatflg_lbl 2 `"Sample adult, no record"', add
label define astatflg_lbl 3 `"Not selected as sample adult"', add
label define astatflg_lbl 4 `"No one selected as sample adult"', add
label define astatflg_lbl 5 `"Armed force member"', add
label define astatflg_lbl 6 `"AF member, selected as sample adult"', add
label values astatflg astatflg_lbl

label define cstatflg_lbl 0 `"NIU"'
label define cstatflg_lbl 1 `"Sample child-has record"', add
label define cstatflg_lbl 2 `"Sample child-no record"', add
label define cstatflg_lbl 3 `"Not selected as sample child"', add
label define cstatflg_lbl 4 `"No one selected as sample child"', add
label define cstatflg_lbl 5 `"Emancipated minor"', add
label values cstatflg cstatflg_lbl

label define age_lbl 00 `"0"'
label define age_lbl 01 `"1"', add
label define age_lbl 02 `"2"', add
label define age_lbl 03 `"3"', add
label define age_lbl 04 `"4"', add
label define age_lbl 05 `"5"', add
label define age_lbl 06 `"6"', add
label define age_lbl 07 `"7"', add
label define age_lbl 08 `"8"', add
label define age_lbl 09 `"9"', add
label define age_lbl 10 `"10"', add
label define age_lbl 11 `"11"', add
label define age_lbl 12 `"12"', add
label define age_lbl 13 `"13"', add
label define age_lbl 14 `"14"', add
label define age_lbl 15 `"15"', add
label define age_lbl 16 `"16"', add
label define age_lbl 17 `"17"', add
label define age_lbl 18 `"18"', add
label define age_lbl 19 `"19"', add
label define age_lbl 20 `"20"', add
label define age_lbl 21 `"21"', add
label define age_lbl 22 `"22"', add
label define age_lbl 23 `"23"', add
label define age_lbl 24 `"24"', add
label define age_lbl 25 `"25"', add
label define age_lbl 26 `"26"', add
label define age_lbl 27 `"27"', add
label define age_lbl 28 `"28"', add
label define age_lbl 29 `"29"', add
label define age_lbl 30 `"30"', add
label define age_lbl 31 `"31"', add
label define age_lbl 32 `"32"', add
label define age_lbl 33 `"33"', add
label define age_lbl 34 `"34"', add
label define age_lbl 35 `"35"', add
label define age_lbl 36 `"36"', add
label define age_lbl 37 `"37"', add
label define age_lbl 38 `"38"', add
label define age_lbl 39 `"39"', add
label define age_lbl 40 `"40"', add
label define age_lbl 41 `"41"', add
label define age_lbl 42 `"42"', add
label define age_lbl 43 `"43"', add
label define age_lbl 44 `"44"', add
label define age_lbl 45 `"45"', add
label define age_lbl 46 `"46"', add
label define age_lbl 47 `"47"', add
label define age_lbl 48 `"48"', add
label define age_lbl 49 `"49"', add
label define age_lbl 50 `"50"', add
label define age_lbl 51 `"51"', add
label define age_lbl 52 `"52"', add
label define age_lbl 53 `"53"', add
label define age_lbl 54 `"54"', add
label define age_lbl 55 `"55"', add
label define age_lbl 56 `"56"', add
label define age_lbl 57 `"57"', add
label define age_lbl 58 `"58"', add
label define age_lbl 59 `"59"', add
label define age_lbl 60 `"60"', add
label define age_lbl 61 `"61"', add
label define age_lbl 62 `"62"', add
label define age_lbl 63 `"63"', add
label define age_lbl 64 `"64"', add
label define age_lbl 65 `"65"', add
label define age_lbl 66 `"66"', add
label define age_lbl 67 `"67"', add
label define age_lbl 68 `"68"', add
label define age_lbl 69 `"69"', add
label define age_lbl 70 `"70"', add
label define age_lbl 71 `"71"', add
label define age_lbl 72 `"72"', add
label define age_lbl 73 `"73"', add
label define age_lbl 74 `"74"', add
label define age_lbl 75 `"75"', add
label define age_lbl 76 `"76"', add
label define age_lbl 77 `"77"', add
label define age_lbl 78 `"78"', add
label define age_lbl 79 `"79"', add
label define age_lbl 80 `"80"', add
label define age_lbl 81 `"81"', add
label define age_lbl 82 `"82"', add
label define age_lbl 83 `"83"', add
label define age_lbl 84 `"84"', add
label define age_lbl 85 `"85 (1963-1968 and 1997 forward: 85+)"', add
label define age_lbl 86 `"86"', add
label define age_lbl 87 `"87"', add
label define age_lbl 88 `"88"', add
label define age_lbl 89 `"89"', add
label define age_lbl 90 `"90 (1996: 90+)"', add
label define age_lbl 91 `"91"', add
label define age_lbl 92 `"92"', add
label define age_lbl 93 `"93"', add
label define age_lbl 94 `"94"', add
label define age_lbl 95 `"95"', add
label define age_lbl 96 `"96"', add
label define age_lbl 97 `"97"', add
label define age_lbl 98 `"98"', add
label define age_lbl 99 `"99+"', add
label values age age_lbl

label define sex_lbl 1 `"Male"'
label define sex_lbl 2 `"Female"', add
label values sex sex_lbl

label define marstat_lbl 00 `"NIU"'
label define marstat_lbl 10 `"Married"', add
label define marstat_lbl 11 `"Married - Spouse present"', add
label define marstat_lbl 12 `"Married - Spouse not in household"', add
label define marstat_lbl 13 `"Married - Spouse in household unknown"', add
label define marstat_lbl 20 `"Widowed"', add
label define marstat_lbl 30 `"Divorced"', add
label define marstat_lbl 40 `"Separated"', add
label define marstat_lbl 50 `"Never married"', add
label define marstat_lbl 99 `"Unknown marital status"', add
label values marstat marstat_lbl

label define racea_lbl 100 `"White"'
label define racea_lbl 200 `"Black/African-American"', add
label define racea_lbl 300 `"Aleut, Alaskan Native, or American Indian"', add
label define racea_lbl 310 `"Alaskan Native or American Indian"', add
label define racea_lbl 320 `"Alaskan Native/Eskimo"', add
label define racea_lbl 330 `"Aleut"', add
label define racea_lbl 340 `"American Indian"', add
label define racea_lbl 400 `"Asian or Pacific Islander"', add
label define racea_lbl 410 `"Asian"', add
label define racea_lbl 411 `"Chinese"', add
label define racea_lbl 412 `"Filipino"', add
label define racea_lbl 413 `"Korean"', add
label define racea_lbl 414 `"Vietnamese"', add
label define racea_lbl 415 `"Japanese"', add
label define racea_lbl 416 `"Asian Indian"', add
label define racea_lbl 420 `"Pacific Islander"', add
label define racea_lbl 421 `"Hawaiian"', add
label define racea_lbl 422 `"Samoan"', add
label define racea_lbl 423 `"Guamanian"', add
label define racea_lbl 430 `"Other Asian or Pacific Islander"', add
label define racea_lbl 431 `"Other Asian or Pacific Islander (1992-1995)"', add
label define racea_lbl 432 `"Other Asian or Pacific Islander (1996)"', add
label define racea_lbl 433 `"Other Asian or Pacific Islander (1997-1998)"', add
label define racea_lbl 434 `"Other Asian (1999 forward)"', add
label define racea_lbl 500 `"Other Race"', add
label define racea_lbl 510 `"Other Race (1969-1977)"', add
label define racea_lbl 520 `"Other Race (1978)"', add
label define racea_lbl 530 `"Other Race (1979-1991)"', add
label define racea_lbl 540 `"Other Race (1992-1995)"', add
label define racea_lbl 550 `"Other Race (1996)"', add
label define racea_lbl 560 `"Other Race (1997-1998)"', add
label define racea_lbl 570 `"Other Race (1999-2002)"', add
label define racea_lbl 580 `"Primary Race not releasable"', add
label define racea_lbl 600 `"Multiple Race, No Primary Race Selected"', add
label define racea_lbl 900 `"Unknown"', add
label define racea_lbl 970 `"Unknown-refused"', add
label define racea_lbl 980 `"Unknown-not ascertained"', add
label define racea_lbl 990 `"Unknown (1997forward: Don't know)"', add
label values racea racea_lbl

label define educrec2_lbl 00 `"NIU"'
label define educrec2_lbl 10 `"Never attended/kindergarten only"', add
label define educrec2_lbl 20 `"Grade 1, 2, 3, or 4"', add
label define educrec2_lbl 30 `"Grade 5, 6, 7, or 8"', add
label define educrec2_lbl 31 `"Grade 5, 6, or 7"', add
label define educrec2_lbl 32 `"Grade 8"', add
label define educrec2_lbl 40 `"Grade 9, 10, 11, or 12"', add
label define educrec2_lbl 41 `"Grade 9, 10, or 11"', add
label define educrec2_lbl 42 `"Grade 12"', add
label define educrec2_lbl 50 `"1 to 4 years of college"', add
label define educrec2_lbl 51 `"1 to 3 years of college"', add
label define educrec2_lbl 52 `"1 to 2 years of college"', add
label define educrec2_lbl 53 `"3 to 4 years of college"', add
label define educrec2_lbl 54 `"4 years college/Bachelor's degree"', add
label define educrec2_lbl 60 `"5+ years of college"', add
label define educrec2_lbl 96 `"Unknown-not reported"', add
label define educrec2_lbl 97 `"Unknown-refused"', add
label define educrec2_lbl 98 `"Unknown-not ascertained"', add
label define educrec2_lbl 99 `"Unknown (1996 forward - Don't know)"', add
label values educrec2 educrec2_lbl

label define higrade2_lbl 00 `"NIU"'
label define higrade2_lbl 10 `"Never attended/kindergarten only"', add
label define higrade2_lbl 20 `"1-7 years completed"', add
label define higrade2_lbl 21 `"1-4 years completed"', add
label define higrade2_lbl 22 `"5-7 years completed"', add
label define higrade2_lbl 30 `"8 years completed"', add
label define higrade2_lbl 40 `"9-11 years completed"', add
label define higrade2_lbl 41 `"9-12 years completed"', add
label define higrade2_lbl 50 `"12 years completed (high school)"', add
label define higrade2_lbl 60 `"13-15 years completed"', add
label define higrade2_lbl 61 `"13-14 years completed"', add
label define higrade2_lbl 62 `"15 years completed"', add
label define higrade2_lbl 63 `"15-16 years completed"', add
label define higrade2_lbl 70 `"16 years completed (college grad)"', add
label define higrade2_lbl 80 `"17+ years completed (grad school)"', add
label define higrade2_lbl 98 `"Unknown - Not Reported"', add
label define higrade2_lbl 99 `"Unknown - All other reasons"', add
label values higrade2 higrade2_lbl

label define educ_lbl 00 `"NIU"'
label define educ_lbl 01 `"Never attended/kindergarten only"', add
label define educ_lbl 02 `"Grade 1"', add
label define educ_lbl 03 `"Grade 2"', add
label define educ_lbl 04 `"Grade 3"', add
label define educ_lbl 05 `"Grade 4"', add
label define educ_lbl 06 `"Grade 5"', add
label define educ_lbl 07 `"Grade 6"', add
label define educ_lbl 08 `"Grade 7"', add
label define educ_lbl 09 `"Grade 8"', add
label define educ_lbl 10 `"Grade 9"', add
label define educ_lbl 11 `"Grade 10"', add
label define educ_lbl 12 `"Grade 11"', add
label define educ_lbl 13 `"12th grade, no diploma"', add
label define educ_lbl 14 `"High school graduate"', add
label define educ_lbl 15 `"GED or equivalent"', add
label define educ_lbl 16 `"Some college, no degree"', add
label define educ_lbl 17 `"AA degree: technical/vocational/occupational"', add
label define educ_lbl 18 `"AA degree: academic program"', add
label define educ_lbl 19 `"Bachelor's degree (BA, AB, BS, BBA)"', add
label define educ_lbl 20 `"Master's degree (MA, MS, Meng, Med, MBA)"', add
label define educ_lbl 21 `"Professional degree (MD, DDS, DVM, JD)"', add
label define educ_lbl 22 `"Doctoral degree (PhD, EdD)"', add
label define educ_lbl 97 `"Unknown--refused"', add
label define educ_lbl 98 `"Unknown--not ascertained"', add
label define educ_lbl 99 `"Unknown--don't know"', add
label values educ educ_lbl

label define health_lbl 1 `"Excellent"'
label define health_lbl 2 `"Very Good"', add
label define health_lbl 3 `"Good"', add
label define health_lbl 4 `"Fair"', add
label define health_lbl 5 `"Poor"', add
label define health_lbl 7 `"Unknown-refused"', add
label define health_lbl 8 `"Unknown-not ascertained"', add
label define health_lbl 9 `"Unknown-don't know"', add
label values health health_lbl

